@@ -1,19 +1,27 @@
 
 
 # from clouderizer_beta.operator_this import AwsLambdaDeploymentOperator
-from clouderizer.operator_this import create_aws_lambda_cloudformation_template_file,create_aws_codebuild_cloudformation_template_file,create_aws_codebuild_buildspec
-from clouderizer.utils import call_sam_command,call_bash,cleanup_build_files,upload_to_showcase,get_creds,parse_json
+# from clouderizer_beta.operator_this import create_aws_lambda_cloudformation_template_file,create_aws_codebuild_cloudformation_template_file,create_aws_codebuild_buildspec
+# from clouderizer_beta.utils import call_sam_command,call_bash,cleanup_build_files,upload_to_showcase,get_creds,parse_json
 import shutil
 import os
 from pathlib import Path
 import json
 import site
 import requests
-from clouderizer import globals
+from clouderizer_beta import globals
 from time import sleep
 import threading
 import sys
 
+dir_name = os.path.dirname(os.path.realpath(__file__)).split("/")[-1]
+if dir_name == "clouderizer_beta" or "beta" in dir_name:
+	from clouderizer_beta.operator_this import create_aws_lambda_cloudformation_template_file,create_aws_codebuild_cloudformation_template_file,create_aws_codebuild_buildspec
+	from clouderizer_beta.utils import call_sam_command,call_bash,cleanup_build_files,upload_to_showcase,get_creds,parse_json
+else:
+	from clouderizer.operator_this import create_aws_lambda_cloudformation_template_file,create_aws_codebuild_cloudformation_template_file,create_aws_codebuild_buildspec
+	from clouderizer.utils import call_sam_command,call_bash,cleanup_build_files,upload_to_showcase,get_creds,parse_json
+
 loadingDisplay=False
 stop_loading_thread=False
 
