@@ -17,22 +17,16 @@ import termcolor
 import random
 import py_compile
 from pathlib import Path
-from clouderizer.cldz_aws_lambda import lambda_deploy, lambda_delete, aws_region_set,lambda_deploy_codebuild
-from clouderizer.utils import check_aws_cli_exists
+# from clouderizer_beta.cldz_aws_lambda import lambda_deploy, lambda_delete, aws_region_set,lambda_deploy_codebuild
+# from clouderizer_beta.utils import check_aws_cli_exists, check_sam_cli_exists
 from yaml import load, dump
+import base64
 # from clouderizer_beta.utils import prepend_line
 try:
     from yaml import CLoader as Loader, CDumper as Dumper
 except ImportError:
     from yaml import Loader, Dumper
 
-# BASE_URL="https://showcase.clouderizer.com"
-BASE_URL="https://showcase.clouderizer.com"
-SYNC_URL="https://serverless.clouderizer.com/function/"
-
-upload_endpoint = BASE_URL + '/api/awsconfig/generatepresignedurl'
-get_user_bucket_endpoint = BASE_URL + '/api/awsconfig/getbucket'
-
 LOCAL_PATH=os.getenv("HOME") + "/.clouderizer/creds"
 LOCAL_DIR=os.getenv("HOME") + "/.clouderizer"
 DOCKERFILES_LOC = LOCAL_DIR+"/dockerfiles/"
@@ -40,10 +34,26 @@ TEMPLATES_LOC = LOCAL_DIR+"/templates/"
 LAMBDA_FUNCTION_DIR = LOCAL_DIR+ "/lambda-dir/function/"
 
 Path(LOCAL_DIR).mkdir(parents=True, exist_ok=True)
-
-if "beta" in BASE_URL:
+dir_name = os.path.dirname(os.path.realpath(__file__)).split("/")[-1]
+if dir_name == "clouderizer_beta" or "beta" in dir_name:
+	from clouderizer_beta.cldz_aws_lambda import lambda_deploy, lambda_delete, aws_region_set,lambda_deploy_codebuild
+	from clouderizer_beta.utils import check_aws_cli_exists, check_sam_cli_exists
+	BASE_URL="https://showcase2.clouderizer.com"
 	Path(LOCAL_DIR+"/beta").mkdir(parents=True,exist_ok=True)
 	LOCAL_PATH = os.getenv("HOME") + "/.clouderizer/beta/creds"
+else:
+	from clouderizer.cldz_aws_lambda import lambda_deploy, lambda_delete, aws_region_set,lambda_deploy_codebuild
+	from clouderizer.utils import check_aws_cli_exists, check_sam_cli_exists
+	BASE_URL="https://showcase.clouderizer.com"
+
+SYNC_URL="https://serverless.clouderizer.com/function/"
+
+#upload_endpoint = BASE_URL + '/api/awsconfig/generatepresignedurl'
+#get_user_bucket_endpoint = BASE_URL + '/api/awsconfig/getbucket'
+
+# if "beta" in BASE_URL:
+# 	Path(LOCAL_DIR+"/beta").mkdir(parents=True,exist_ok=True)
+# 	LOCAL_PATH = os.getenv("HOME") + "/.clouderizer/beta/creds"
 
 dockerfiles = ['AutomlDockerfile','PythonDockerfile']
 for dockerfile in dockerfiles:
@@ -368,6 +378,7 @@ def pipreqsnb_main(input_path):
 
 def upload_to_showcase(file_name,file_loc,company,auth_token):
 	print("Uploading to Clouderizer.....")
+	upload_endpoint = BASE_URL + '/api/awsconfig/generatepresignedurl'
 	resp=requests.post(upload_endpoint,json={
 			"type":"put",
 			"key": file_name,
@@ -396,6 +407,7 @@ def upload_to_showcase(file_name,file_loc,company,auth_token):
 	return "Some error occurred while uploading... try again"
 
 def get_user_s3_bucket(company,auth_token):
+	get_user_bucket_endpoint = BASE_URL + '/api/awsconfig/getbucket'
 	resp=requests.post(get_user_bucket_endpoint,json={
 			"company": company
 	},headers={"Content-Type":"application/json","Authorization": "Bearer "+auth_token})
@@ -665,6 +677,7 @@ def get_serving_model(servingprojectid,retry=0):
 	return get_serving_model(id,retry)
 
 def get_presigned_url(file_name,file_loc,company,auth_token,retry=0):
+	upload_endpoint = BASE_URL + '/api/awsconfig/generatepresignedurl'
 	resp=requests.post(upload_endpoint,json={
 		"type":"get",
 		"key": file_name,
@@ -848,9 +861,13 @@ def invoke_publishproject(servingprojectid, infra, auth_token, invokepublishproj
 		if publishproject.status_code==500:
 			text = parse_json(publishproject.text)
 			if "success" in text:
-				return text['message']
+				print(text['message'])
+				exit(0)
+				# return text['message']
 			else:
-				return text
+				print("Some error occurred")
+				exit(0)
+				# return text
 		return "Could not publish project"
 
 def invoke_deployproject(servingprojectid, auth_token):
@@ -927,42 +944,66 @@ class Clouderizer(object):
 
 	def login(self,token=None):
 		if not token:
-			print("Follow this url and get an authentication token: "+ BASE_URL +"/api/auth/google?source=cli")
+			print("@@@@@@@Follow this url and get an authentication token: "+ BASE_URL +"/api/auth/google?source=cli")
 			webbrowser.open(BASE_URL+'/api/auth/google?source=cli', new=1, autoraise=True)
 			apiKey= input("Paste your authentication token:")
 
+			# try:
+			# 	payload=jwt.decode(apiKey,'oursecret', algorithms=['HS256'])
+			# except Exception as e:
+			# 	print("Could not verify token. Is it correct?")
+			# 	return
+
+			# payload["token"]=apiKey
 			try:
-				payload=jwt.decode(apiKey,'oursecret', algorithms=['HS256'])
+				apiKey_json_str = base64.b64decode(apiKey)
+				payload = parse_json(apiKey_json_str)
+				print(payload)
+
 			except Exception as e:
 				print("Could not verify token. Is it correct?")
 				return
-
-			payload["token"]=apiKey
 			headers = {"Authorization":"Bearer "+payload["token"]}
 
 		else:
-			try:
-				payload=jwt.decode(token,'oursecret', algorithms=['HS256'])
-			except Exception as e:
-				print("token verification failed. Is it correct?")
-				return
+			# try:
+			# 	payload=jwt.decode(token,'oursecret', algorithms=['HS256'])
+			# except Exception as e:
+			# 	print("token verification failed. Is it correct?")
+			# 	return
 
-			payload["token"]=token
+			# payload["token"]=token
+			try:
+				apiKey_json_str = base64.b64decode(token)
+				payload = parse_json(apiKey_json_str)
+
+			except Exception as e:
+				print("Could not verify token. Is it correct?")
+				return
 			headers = {"Authorization":"Bearer "+payload["token"]}
 
-		# get company dets		
-		customer_dets=requests.get(BASE_URL+'/api/customer/'+payload['cid'],headers=headers)
-		customer_dets=parse_json(customer_dets.text)
 
-		# get user dets
-		user_dets=requests.get(BASE_URL+'/api/user/'+payload['uid'],headers=headers)
-		user_dets=parse_json(user_dets.text)
+		try:
+			jwt_payload=jwt.decode(payload['token'],'oursecret', algorithms=['HS256'])
+		except Exception as e:
+			print("Some error occurred")
+			return
 
-		if "name" in customer_dets:
-			payload["Company"]=customer_dets["name"]
+		payload['cid'] = jwt_payload['cid']
+		payload['uid'] = jwt_payload['uid']
+		# # get company dets		
+		# customer_dets=requests.get(BASE_URL+'/api/customer/'+payload['cid'],headers=headers)
+		# customer_dets=parse_json(customer_dets.text)
+
+		# # get user dets
+		# user_dets=requests.get(BASE_URL+'/api/user/'+payload['uid'],headers=headers)
+		# user_dets=parse_json(user_dets.text)
+
+		# if "name" in customer_dets:
+		# 	payload["Company"]=customer_dets["name"]
 		
-		if "name" in user_dets:
-			payload["User"]=user_dets["name"]
+		# if "name" in user_dets:
+		# 	payload["User"]=user_dets["name"]
 
 		payload['projects']=[]
 
@@ -985,7 +1026,6 @@ class Clouderizer(object):
 
 		createEvent("login success",payload['cid'],payload['token'])
 
-
 	def ls(self):
 		# get list of projects in published serving project
 		creds = self.loggedin()
@@ -1167,7 +1207,7 @@ class Clouderizer(object):
 			print("Some error occurred")
 
 
-	def deploy(self, name,infra="standard",image="standard"):
+	def start(self, name,infra="standard",image="standard"):
 		global loadingDisplay
 		if not name:
 			print("Choose a specific project!")
@@ -1388,6 +1428,8 @@ class Clouderizer(object):
 		#       print("Training URL will be accessible here after project gets deployed!")
 
 	def loggedin(self):
+		global BASE_URL
+		global SYNC_URL
 		# have a .cldzrc file which stores api key
 		creds=None
 		if os.path.exists(LOCAL_PATH):
@@ -1400,6 +1442,10 @@ class Clouderizer(object):
 					#   print(e)
 					#   print("Couldn't verify your credentials, please login again")
 					#   return
+
+					#update BASE_URL from creds
+					BASE_URL=creds["url"]
+					SYNC_URL=creds["surl"]
 					return creds
 				else:
 					print("You are not logged in, try: cldz login.")
@@ -1507,7 +1553,7 @@ class Clouderizer(object):
 				print("Updating requirements file")
 				servingmodel["pipPackages"]=pipPackages
 
-			servingmodel["savedon"] int(time())
+			servingmodel["savedon"]=int(time())
 			updated_model=requests.put(BASE_URL+"/api/servingmodel/"+servingmodel["id"],headers=headers,data=servingmodel)
 				# print(updated_model.text)
 			print("Model updated successfully!")
