@@ -18,7 +18,7 @@ import shutil
 import uuid
 import logging
 from pathlib import Path
-from clouderizer import globals
+from clouderizer_beta import globals
 
 # import boto3
 
