@@ -27,7 +27,7 @@ import requests
 # from bentoml.exceptions import BentoMLException
 # from bentoml.yatai.deployment.aws_utils import call_sam_command
 import subprocess
-from clouderizer import globals
+from clouderizer_beta import globals
 
 logger = logging.getLogger(__name__)
 
